#email-subnav {
  padding-bottom: 1em;
}

#email-search-form {
   padding-bottom: 1em;
}

.btn-group.email-actions {
  margin-top: 1em;
}

.panel-title .email-row {
  text-decoration: none;
  word-wrap: break-word;
}
